@@ -16,14 +16,17 @@ def make_con_info(
 ):
     # ---------------- 固定设置 ----------------
     inner_env = envx.read(file_name=env_file_name)
-    con_info = {
-        "host": inner_env.get('host', 'localhost'),
-        "port": int(inner_env.get('port', '6379')),
-        "password": inner_env.get('password'),
-        "max_connections": int(inner_env.get('max_connections', '10')),
-    }
-    # ---------------- 固定设置 ----------------
-    return con_info
+    if len(inner_env) == 0:
+        showlog.warning('Please check that the file exists and meets the requirements. File:[%s]' % env_file_name)
+        return
+    else:
+        con_info = {
+            "host": inner_env.get('host', 'localhost'),
+            "port": int(inner_env.get('port', '6379')),
+            "password": inner_env.get('password'),
+            "max_connections": int(inner_env.get('max_connections', '10')),
+        }
+        return con_info
 
 
 class Basics:
@@ -94,6 +97,27 @@ class Basics:
             key_list.append(key.decode())
         return key_list
 
+    def read_list_key_values_length(
+            self,
+            key,
+            connection=None
+    ):
+        """
+        读取指定库的指定键的值列表元素数量
+        """
+        if connection is None:
+            conn = self.connection
+        else:
+            conn = connection
+
+        while True:
+            try:
+                values_count = conn.llen(key)  # 获取列表元素个数
+                return values_count
+            except:
+                showlog.error('获取失败，准备重连')
+                self.connection = self.connect()
+
     def read_list_key_values(
             self,
             key,
@@ -293,6 +317,24 @@ class Basics:
                 showlog.error('获取失败，准备重连')
                 self.connection = self.connect()
 
+    def count_set(
+            self,
+            key,
+            value,
+            connection=None
+    ):
+        # 键 计数 设定值
+        if connection is None:
+            conn = self.connection
+        else:
+            conn = connection
+        while True:
+            try:
+                return conn.set(name=key, value=value)
+            except:
+                showlog.error('获取失败，准备重连')
+                self.connection = self.connect()
+
     def count_add(
             self,
             key,
@@ -341,7 +383,7 @@ class Basics:
             try:
                 count_value = conn.get(key)
                 if count_value is None:
-                    return 0
+                    return
                 else:
                     return count_value.decode()
             except:
@@ -491,6 +533,36 @@ def read_list_last_value(
     )
 
 
+def count_set(
+        key,
+        value,
+        db: int = None,
+        con_info: dict = None,  # 若指定，将优先使用
+        env_file_name: str = 'redis.env'
+):
+    # 键 计数 设定值
+    # ---------------- 固定设置 ----------------
+    if con_info is None:
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
+    else:
+        pass
+    if db is None:
+        db = 0
+    else:
+        pass
+    con_info['db'] = db
+    # ---------------- 固定设置 ----------------
+    basics = Basics(
+        con_info=con_info
+    )
+    return basics.count_set(
+        key=key,
+        value=value
+    )
+
+
 def count_add(
         key,
         db: int = None,
@@ -573,3 +645,31 @@ def count_get(
     return basics.count_get(
         key=key
     )
+
+
+def read_list_key_values_length(
+        key,
+        db: int = None,
+        con_info: dict = None,  # 若指定，将优先使用
+        env_file_name: str = 'redis.env'
+):
+    # 键 获取列表元素数量
+    # ---------------- 固定设置 ----------------
+    if con_info is None:
+        con_info = make_con_info(
+            env_file_name=env_file_name
+        )
+    else:
+        pass
+    if db is None:
+        db = 0
+    else:
+        pass
+    con_info['db'] = db
+    # ---------------- 固定设置 ----------------
+    basics = Basics(
+        con_info=con_info
+    )
+    return basics.read_list_key_values_length(
+        key=key
+    )
